@@ -1,8 +1,6 @@
 from typing import Callable, List, Generator
 
-_accept_byte = lambda c: not (
-    c < 122 if c > 96 else c > 64 or c < 33 or c == 45 if c < 91 else False
-)
+_accept_byte = lambda c: c < 122 if c > 96 else c > 64 or c < 33 or c == 45 if c < 91 else False
 
 def word_tokenize(text: str):
     for char in ("-", "—"):
